@@ -7,7 +7,8 @@
 
 ``rebuild_mptt`` rebuilds your mptt pointers. Only use in emergencies.
 """
-from __future__ import print_function
+
+from __future__ import absolute_import, print_function, unicode_literals
 
 from django.core.management.base import NoArgsCommand
 
