@@ -400,13 +400,13 @@ def create_base_model(inherit_from=models.Model):
                         # return first template as a fallback if the template
                         # has changed in-between
                         return self._feincms_templates[
-                            self._feincms_templates.keys()[0]]
+                            list(self._feincms_templates.keys())[0]]
 
                 cls.template = property(_template)
 
             cls.TEMPLATE_CHOICES = field._choices = [
-                (template.key, template.title,)
-                for template in cls._feincms_templates.values()
+                (template_.key, template_.title,)
+                for template_ in cls._feincms_templates.values()
             ]
             field.default = field.choices[0][0]
 
