@@ -8,6 +8,8 @@ the page's manager to determine which entries are to be considered active.
 """
 # ------------------------------------------------------------------------
 
+from __future__ import absolute_import, unicode_literals
+
 from datetime import datetime
 
 from django.db import models
@@ -118,7 +120,7 @@ class Extension(extensions.Extension):
 
     def handle_modeladmin(self, modeladmin):
         def datepublisher_admin(self, obj):
-            return u'%s &ndash; %s' % (
+            return '%s &ndash; %s' % (
                 format_date(obj.publication_date),
                 format_date(obj.publication_end_date, '&infin;'),
             )
