@@ -2,6 +2,8 @@
 # coding=utf-8
 # ------------------------------------------------------------------------
 
+from __future__ import absolute_import, unicode_literals
+
 import logging
 
 from django import template
@@ -46,7 +48,7 @@ def feincms_render_region(context, feincms_object, region, request=None):
     """
     {% feincms_render_region feincms_page "main" request %}
     """
-    return u''.join(
+    return ''.join(
         _render_content(content, request=request, context=context)
         for content in getattr(feincms_object.content, region))
 
@@ -72,7 +74,7 @@ def feincms_frontend_editing(cms_obj, request):
         })
         return render_to_string('admin/feincms/fe_tools.html', context)
 
-    return u''
+    return ''
 
 
 @register.inclusion_tag('admin/feincms/content_type_selection_widget.html',
